package com.ruoyi.cs.mapper;

import java.util.Date;
import java.util.List;
import com.ruoyi.cs.domain.CsAchievementInfo;
import com.ruoyi.cs.domain.CsAchievementInfoDetails;
import com.ruoyi.cs.domain.dto.CsAchievementPaperDetailsDTO;
import org.apache.ibatis.annotations.Param;

/**
 * 科研成果信息Mapper接口
 *
 * @author ruoyi
 * @date 2024-05-08
 */
public interface CsAchievementInfoMapper
{
    /**
     * 查询科研成果信息
     *
     * @param achievementInfoId 科研成果信息主键
     * @return 科研成果信息
     */
    public CsAchievementInfo selectCsAchievementInfoByAchievementInfoId(String achievementInfoId);

    /**
     * 查询科研成果信息列表
     *
     * @param csAchievementInfo 科研成果信息
     * @return 科研成果信息集合
     */
    public List<CsAchievementInfo> selectCsAchievementInfoList(CsAchievementInfo csAchievementInfo);

    /**
     * 新增科研成果信息
     *
     * @param csAchievementInfo 科研成果信息
     * @return 结果
     */
    public int insertCsAchievementInfo(CsAchievementInfo csAchievementInfo);

    /**
     * 修改科研成果信息
     *
     * @param csAchievementInfo 科研成果信息
     * @return 结果
     */
    public int updateCsAchievementInfo(CsAchievementInfo csAchievementInfo);

    /**
     * 删除科研成果信息
     *
     * @param achievementInfoId 科研成果信息主键
     * @return 结果
     */
    public int deleteCsAchievementInfoByAchievementInfoId(String achievementInfoId);

    /**
     * 批量删除科研成果信息
     *
     * @param achievementInfoIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCsAchievementInfoByAchievementInfoIds(String[] achievementInfoIds);

    /**
     * 查询科研成果信息
     *
     * @param resId 相关资源ID
     * @return 科研成果信息
     */
    public CsAchievementInfo selectCsAchievementInfoByResId(String resId);

    /**
     * 修改科研成果信息
     *
     * @param csAchievementInfo 科研成果信息
     * @return 结果
     */
    public int updateCsAchievementInfoByResId(CsAchievementInfo csAchievementInfo);
}
